@@ -1,5 +1,5 @@
-# This code is part of Perl distribution OODoc version 3.03.
-# The POD got stripped from this file by OODoc version 3.03.
+# This code is part of Perl distribution OODoc version 3.04.
+# The POD got stripped from this file by OODoc version 3.04.
 # For contributors see file ChangeLog.
 
 # This software is copyright (c) 2003-2025 by Mark Overmeer.
@@ -15,7 +15,7 @@
 #oodist: testing, however the code of this development version may be broken!
 
 package OODoc::Format::Pod;{
-our $VERSION = '3.03';
+our $VERSION = '3.04';
 }
 
 use parent 'OODoc::Format';
@@ -76,7 +76,7 @@ sub createManual($@)
 	my $tmpfile  = catfile $self->workdir, $tmpname;
 	my $podfile  = catfile $self->workdir, $podname;
 
-	open my $output, '>:encoding(utf8)', $tmpfile
+	open my $output, '>:encoding(UTF-8)', $tmpfile
 		or fault __x"cannot write prelimary pod manual to {file}", file => $tmpfile;
 
 	$self->_formatManual(
@@ -496,10 +496,10 @@ sub showSubsIndex() {;}
 sub simplifyPod($$)
 {	my ($self, $infn, $outfn) = @_;
 
-	open my $in, "<:encoding(utf8)", $infn
+	open my $in, '<:encoding(UTF-8)', $infn
 		or fault __x"cannot read prelimary pod from {file}", file => $infn;
 
-	open my $out, ">:encoding(utf8)", $outfn
+	open my $out, '>:encoding(UTF-8)', $outfn
 		or fault __x"cannot write final pod to {file}", file => $outfn;
 
 	my $last_is_blank = 1;
