@@ -1,5 +1,5 @@
-# This code is part of Perl distribution OODoc version 3.03.
-# The POD got stripped from this file by OODoc version 3.03.
+# This code is part of Perl distribution OODoc version 3.04.
+# The POD got stripped from this file by OODoc version 3.04.
 # For contributors see file ChangeLog.
 
 # This software is copyright (c) 2003-2025 by Mark Overmeer.
@@ -14,7 +14,7 @@
 #oodist: testing, however the code of this development version may be broken!
 
 package OODoc::Parser::Markov;{
-our $VERSION = '3.03';
+our $VERSION = '3.04';
 }
 
 use parent 'OODoc::Parser';
@@ -163,10 +163,10 @@ sub parse(@)
 	my $version = $args{version}      or panic;
 	my $distr   = $args{distribution} or panic;
 
-	open my $in, '<:encoding(utf8)', $input
+	open my $in, '<:encoding(UTF-8)', $input
 		or fault __x"cannot read document from {file}", file => $input;
 
-	open my $out, '>:encoding(utf8)', $output
+	open my $out, '>:encoding(UTF-8)', $output
 		or fault __x"cannot write stripped code to {file}", file => $output;
 
 	# pure doc files have no package statement included, so it shall
@@ -746,17 +746,24 @@ sub cleanupPodL($$$)
 sub _htmlReformat($$$$)
 {	my ($self, $manual, $key, $body, $args) = @_;
 		$key eq 'B' ? "<b>$body</b>"
-	: $key eq 'C' ? "<code>$body</code>"
-	: $key eq 'E' ? "&$body;"
-	: $key eq 'F' ? qq{<i class="filename">$body</i>}
-	: $key eq 'I' ? "<i>$body</i>"
-	: $key eq 'L' ? $self->cleanupHtmlL($manual, $body, $args)
-	: $key eq 'M' ? $self->cleanupHtmlM($manual, $body, $args)
-	: $key eq 'P' ? qq{<tt class="parameter">$body</tt>}
-	: $key eq 'S' ? $body =~ s/[ ]/&nbsp;/gr
-	: $key eq 'X' ? ''
-	: $key eq 'Z' ? '&ZeroWidthSpace;'
-	: error __x"Unknown format key '{key}' in manual {manual}", key => $key, manual => $manual->name;
+	  : $key eq 'C' ? "<code>$body</code>"
+	  : $key eq 'E' ? "&$body;"
+	  : $key eq 'F' ? qq{<i class="filename">$body</i>}
+	  : $key eq 'I' ? "<i>$body</i>"
+	  : $key eq 'L' ? $self->cleanupHtmlL($manual, $body, $args)
+	  : $key eq 'M' ? $self->cleanupHtmlM($manual, $body, $args)
+	  : $key eq 'P' ? qq{<tt class="parameter">$body</tt>}
+	  : $key eq 'S' ? $body =~ s/[ ]/&nbsp;/gr
+	  : $key eq 'X' ? ''
+	  : $key eq 'Z' ? '&ZeroWidthSpace;'
+	  :   error __x"Unknown format key '{key}' in manual {manual}", key => $key, manual => $manual->name;
+}
+
+sub _htmlItems($)
+{	my ($self, $manual, $block) = @_;
+	my $type = $block =~ m!^=item\s+\d+\.!m ? 'ol' : 'ul';
+	$block =~ s#^\=item\s*(?:\*\s*|\d+\.\s*)?([^\n]*)#\n<li>$1<br />#gms;
+	"<$type>$block</$type>";
 }
 
 sub cleanupHtml($$$)
@@ -765,10 +772,10 @@ sub cleanupHtml($$$)
 
 	my $is_html = $args{is_html};
 
-	if($string =~ m/(?:\A|\n)                   # start of line
-					\=begin\s+(:?\w+)\s*        # begin statement
-					(.*?)                       # encapsulated
-					\n\=end\s+\1\s*             # related end statement
+	if($string =~ m/(?:\A|\n)                  # start of line
+					\=begin\s+(:?\w+)\s*       # begin statement
+					(.*?)                      # encapsulated
+					\n\=end\s+\1\s*            # related end statement
 					/xs
 	|| $string =~ m/(?:\A|\n)                  # start of line
 					\=for\s+(:?\w+)\b          # for statement
@@ -777,6 +784,7 @@ sub cleanupHtml($$$)
 					/xs
 	)
 	{	my ($before, $type, $capture, $after) = ($`, lc($1), $2, $');
+
 		if($type =~ m/^\:?html\b/ )
 		{	$type    = 'html';
 			$capture = $self->cleanupHtml($manual, $capture, is_html => 1);
@@ -789,15 +797,13 @@ sub cleanupHtml($$$)
 	{	unless($is_html)
 		{	s#\&#\&amp;#g;
 			s#(\s|^) \< ([^<>]+) \> #$1&lt;$2&gt;#gx;
-			s#(?<!\b[BCEFILSXMP<])\<#&lt;#g;
+#			s#(?<!\b[BCEFILSXMP<])\<#&lt;#g;
 			s#([=-])\>#$1\&gt;#g;
 		}
-		s# \b ([A-Z]) (?: \<\<\s*(.*?)\s*\>\> | \<(.*?)\> ) #
+		s# ([A-Z]) (?: \<\<\s*(.*?)\s*\>\> | \<(.*?)\> ) #
 			$self->_htmlReformat($manual, $1, $+, \%args) #gxe;
 
-		s#^\=over(?:\s+\d+)?\s*$#\n<ul>\n#gms;
-		s#^\=item\s*(?:\*\s*)?([^\n]*)#\n<li>$1<br />#gms;
-		s#^\=back\b#\n</ul>#gms;
+		s#^\=over(?:\s+\d+)?(.*?)\n=back#$self->_htmlItems($manual, $1)#gmes;
 		s#^\=pod\b##gm;
 
 		my ($label, $level, $title);
@@ -809,15 +815,15 @@ sub cleanupHtml($$$)
 
 		next if $is_html;
 
-		s!(?:(?:^|\n)
+		s!((?:(?:^|\n)
 			[^\ \t\n]+[^\n]*      # line starting with blank: para
-		)+
-		!<p>$&</p>!gsx;
+		)+)
+		!<p>$1</p>!gsx;
 
-		s!(?:(?:^|\n)               # start of line
+		s!((?:(?:^|\n)            # start of line
 			[\ \t]+[^\n]+         # line starting with blank: pre
-		)+
-		!<pre>$&\n</pre>!gsx;
+		)+)
+		!<pre>$1\n</pre>!gsx;
 
 		s#</pre>\n<pre>##gs;
 		s#<p>\n#\n<p>#gs;
@@ -962,8 +968,8 @@ sub autoMarkup($$%)
 			my $q    = $self->_collectParams($p, default => $v);
 
 			# modify the default value
-			my $w    = $self->_markupText($v, "$w(D=$name)", %args, params => $q);
-			$default->_setValue($w);
+			my $dv   = $self->_markupText($v, "$w(D=$name)", %args, params => $q);
+			$default->_setValue($dv);
 
 			# modify the option text
 			my $opt  = $option->openDescription;
